@@ -1,13 +1,28 @@
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
+##
+#
+# Out of the box this script hardly touches the functionality of LJ::Simple
+# thanks to the removal of the test user on www.livejournal.com.
+#
+# If people wish they can place another username and password in the $user
+# and $pass variables in test.pl to run all of the test.pl Bear in mind that
+# I'm not going to be held responsible for what happens to the journal that
+# this script is pointed at though.
+#
+##
+
 #########################
 use Test;
-BEGIN { plan tests => 99 };
+BEGIN { plan tests => 26 };
 use LJ::Simple;
 ok(1); # If we made it this far, we're ok.
 #########################
 
+my $user="test";
+my $pass="test";
+
 #goto LOGIN;
 
 ## Test object creation via new - should fail
@@ -51,7 +66,7 @@ if (defined $lj) {
 
 ## Test object creation with a valid user, but invalid password
 $lj = new LJ::Simple ({
-	user	=>	"test",
+	user	=>	$user,
 	pass	=>	"testy",
 	site	=>	undef,
 	proxy	=>	undef,
@@ -66,8 +81,8 @@ if (defined $lj) {
 ## A couple of tests to make sure that certains occur as documented
 ##
 $lj = new LJ::Simple ({
-        user    =>      "test",
-        pass    =>      "test",
+        user    =>      $user,
+        pass    =>      $pass,
         site    =>      undef,
         proxy   =>      undef,
 	moods	=>	0,
@@ -85,10 +100,16 @@ if (!defined $lj->pictures(\%Ref)) {
 } else {
   ok(0);
 }
+if (!defined $lj->DefaultPicURL()) {
+  if ($LJ::Simple::error=~/none defined/) {ok(1)} else {ok(0)}
+} else {
+  ok(0);
+}
+
 # Fast login
 $lj = new LJ::Simple ({
-        user    =>      "test",
-        pass    =>      "test",
+        user    =>      $user,
+        pass    =>      $pass,
         site    =>      undef,
         proxy   =>      undef,
 	fast	=>	1,
@@ -135,8 +156,8 @@ LOGIN:
 
 ## Test object creation with a valid username and password
 $lj = new LJ::Simple ({
-	user	=>	"test",
-	pass	=>	"test",
+	user	=>	$user,
+	pass	=>	$pass,
 	site	=>	undef,
 	proxy	=>	undef,
       });
@@ -147,7 +168,7 @@ if (defined $lj) {
   print STDERR "  Error was: $LJ::Simple::error\n";
 }
 
-#goto JTEST1;
+#goto JTEST;
 
 my $msg=$lj->message();
 ok(1);
@@ -177,6 +198,9 @@ my %pictures=();
 $lj->pictures(\%pictures);
 ok(1);
 
+## We stop here if we're the now dead test user
+($user eq "test") && exit 0;
+
 my %Event=();
 
 ## Ensure that stuff for posting journal entrie doesn't work until
@@ -460,9 +484,9 @@ if (defined $lj->GetEntries(\%Entry,undef,"one",$item_id)) {
 }
 if ($NewText eq $lj->GetEntry($Entry{$item_id})) { ok(1) } else { ok(0) }
 
-JTEST:
-
 ## Be nice and remove the test entry
 if (!$lj->DeleteEntry($item_id)) { ok(0) } else { ok(1) }
 
+JTEST:
+
 exit 0;
